package_name = 'celery_redis_unixsocket'
name = 'celery-redis-unixsocket'
author = 'Benjamin Wohlwend'
author_email = 'piquadrat@gmail.com'
description = "celery store backend and kombu transport for redis that supports connections via unix sockets"
version = __import__(package_name).__version__
project_url = 'http://github.com/piquadrat/%s' % name
license = 'BSD'
